Models reference — django-authopenid v1.0 documentation

### Navigation

- index
- next |
- previous |
- django-authopenid v1.0 documentation »

# Models reference

## User association

This class manage association between an openid and a user account.

class `django_authopenid.models.` `UserAssociation`(*args, **kwargs)
  model to manage association between openid and user

## Openid store

In django-authopenid we create a special openid store (an instance of `django_authopenid.openid_store.DjangoOpenIDStore` using Django ORM. It use theses classes to store associations and nonces.

class `django_authopenid.models.` `Nonce`(*args, **kwargs)
  openid nonce

class `django_authopenid.models.` `Association`(*args, **kwargs)
  association openid url and lifetime

See also

python-openid documentation and django-registration models documentation for more informations

### Navigation

- index
- next |
- previous |
- django-authopenid v1.0 documentation »